# Werewolves!

Player Secret Information

User ID: |
Role dealt: |

Game Information

Game Information
Role Name | Count
--- | ---

### Post Game Results

####

Voting Results
Player | Eliminated? | Voted For
--- | --- | ---

Player Roles
Player | Starting Role | Final Role
--- | --- | ---

Table Roles
Starting Role | Final Role
--- | ---

Phase Instructions
Initializing ...
Actions
Chat

##### Werewolves! Settings

Seer
Robber
Troublemaker
Minion
Insomniac
Hunter
Tanner
Werewolves: